@@ -2,7 +2,6 @@ import logging
 from typing import Any, Dict, Optional, Tuple
 
 from uaclient import (
-    api,
     event_logger,
     exceptions,
     http,
@@ -12,7 +11,7 @@ from uaclient import (
     system,
     util,
 )
-from uaclient.entitlements.base import EntitlementWithMessage, UAEntitlement
+from uaclient.entitlements.base import IncompatibleService, UAEntitlement
 from uaclient.entitlements.entitlement_status import ApplicationStatus
 from uaclient.types import StaticAffordance
 
@@ -42,15 +41,15 @@ class LivepatchEntitlement(UAEntitlement):
     affordance_check_arch = True
 
     @property
-    def incompatible_services(self) -> Tuple[EntitlementWithMessage, ...]:
+    def incompatible_services(self) -> Tuple[IncompatibleService, ...]:
         from uaclient.entitlements.fips import FIPSEntitlement
         from uaclient.entitlements.realtime import RealtimeKernelEntitlement
 
         return (
-            EntitlementWithMessage(
+            IncompatibleService(
                 FIPSEntitlement, messages.LIVEPATCH_INVALIDATES_FIPS
             ),
-            EntitlementWithMessage(
+            IncompatibleService(
                 RealtimeKernelEntitlement,
                 messages.REALTIME_LIVEPATCH_INCOMPATIBLE,
             ),
@@ -61,7 +60,7 @@ class LivepatchEntitlement(UAEntitlement):
         # Use a lambda so we can mock system.is_container in tests
         from uaclient.entitlements.fips import FIPSEntitlement
 
-        fips_ent = FIPSEntitlement(cfg=self.cfg)
+        fips_ent = FIPSEntitlement(self.cfg)
 
         is_fips_enabled = bool(
             fips_ent.application_status()[0] == ApplicationStatus.ENABLED
@@ -72,8 +71,7 @@ class LivepatchEntitlement(UAEntitlement):
                 messages.SERVICE_ERROR_INSTALL_ON_CONTAINER.format(
                     title=self.title
                 ),
-                lambda: system.is_container()
-                or system.get_virt_type() == "wsl",
+                lambda: system.is_container(),
                 False,
             ),
             (
@@ -83,52 +81,30 @@ class LivepatchEntitlement(UAEntitlement):
             ),
         )
 
-    def enable_steps(self) -> int:
-        return 2
-
-    def disable_steps(self) -> int:
-        return 1
-
-    def _perform_enable(self, progress: api.ProgressWrapper) -> bool:
+    def _perform_enable(self, silent: bool = False) -> bool:
         """Enable specific entitlement.
 
         @return: True on success, False otherwise.
         """
-        progress.progress(messages.INSTALLING_LIVEPATCH)
-
         if not snap.is_snapd_installed():
-            progress.emit(
-                "info", messages.INSTALLING_PACKAGES.format(packages="snapd")
-            )
+            event.info(messages.INSTALLING_PACKAGES.format(packages="snapd"))
             snap.install_snapd()
 
         if not snap.is_snapd_installed_as_a_snap():
-            progress.emit(
-                "info",
-                messages.INSTALLING_PACKAGES.format(packages="snapd snap"),
+            event.info(
+                messages.INSTALLING_PACKAGES.format(packages="snapd snap")
             )
             try:
                 snap.install_snap("snapd")
             except exceptions.ProcessExecutionError as e:
                 LOG.warning("Failed to install snapd as a snap", exc_info=e)
-                progress.emit(
-                    "info",
+                event.info(
                     messages.EXECUTING_COMMAND_FAILED.format(
                         command="snap install snapd"
-                    ),
+                    )
                 )
 
-        snap.run_snapd_wait_cmd(progress)
-
-        try:
-            snap.refresh_snap("snapd")
-        except exceptions.ProcessExecutionError as e:
-            LOG.warning("Failed to refresh snapd snap", exc_info=e)
-            event.info(
-                messages.EXECUTING_COMMAND_FAILED.format(
-                    command="snap refresh snapd"
-                )
-            )
+        snap.run_snapd_wait_cmd()
 
         http_proxy = http.validate_proxy(
             "http", self.cfg.http_proxy, http.PROXY_VALIDATION_SNAP_HTTP_URL
@@ -142,11 +118,10 @@ class LivepatchEntitlement(UAEntitlement):
             retry_sleeps=snap.SNAP_INSTALL_RETRIES,
         )
         if not livepatch.is_livepatch_installed():
-            progress.emit(
-                "info",
+            event.info(
                 messages.INSTALLING_PACKAGES.format(
                     packages="canonical-livepatch snap"
-                ),
+                )
             )
             try:
                 snap.install_snap("canonical-livepatch")
@@ -156,14 +131,11 @@ class LivepatchEntitlement(UAEntitlement):
         livepatch.configure_livepatch_proxy(http_proxy, https_proxy)
 
         return self.setup_livepatch_config(
-            progress, process_directives=True, process_token=True
+            process_directives=True, process_token=True
         )
 
     def setup_livepatch_config(
-        self,
-        progress: api.ProgressWrapper,
-        process_directives: bool = True,
-        process_token: bool = True,
+        self, process_directives: bool = True, process_token: bool = True
     ) -> bool:
         """Processs configuration setup for livepatch directives.
 
@@ -172,19 +144,18 @@ class LivepatchEntitlement(UAEntitlement):
         :param process_token: Boolean set True when token should be
             processsed.
         """
-        progress.progress(messages.SETTING_UP_LIVEPATCH)
-
-        entitlement_cfg = self.machine_token_file.entitlements().get(self.name)
+        entitlement_cfg = self.cfg.machine_token_file.entitlements.get(
+            self.name
+        )
         if process_directives:
             try:
                 process_config_directives(entitlement_cfg)
             except exceptions.ProcessExecutionError as e:
                 LOG.error(str(e), exc_info=e)
-                progress.emit(
-                    "info",
+                event.info(
                     messages.LIVEPATCH_UNABLE_TO_CONFIGURE.format(
                         error_msg=str(e)
-                    ),
+                    )
                 )
                 return False
         if process_token:
@@ -195,13 +166,11 @@ class LivepatchEntitlement(UAEntitlement):
                     " %s credentials",
                     self.title,
                 )
-                livepatch_token = self.machine_token_file.machine_token[
-                    "machineToken"
-                ]
+                livepatch_token = self.cfg.machine_token["machineToken"]
             application_status, _details = self.application_status()
             if application_status != ApplicationStatus.DISABLED:
                 LOG.info("Disabling livepatch before re-enabling")
-                progress.emit("info", messages.LIVEPATCH_DISABLE_REATTACH)
+                event.info(messages.LIVEPATCH_DISABLE_REATTACH)
                 try:
                     system.subp([livepatch.LIVEPATCH_CMD, "disable"])
                 except exceptions.ProcessExecutionError as e:
@@ -220,22 +189,21 @@ class LivepatchEntitlement(UAEntitlement):
                         break
                 if msg == messages.LIVEPATCH_UNABLE_TO_ENABLE:
                     msg += str(e)
-                progress.emit("info", msg)
+                event.info(msg)
                 return False
+            event.info(
+                messages.ENABLED_TMPL.format(title="Canonical Livepatch")
+            )
         return True
 
-    def _perform_disable(self, progress: api.ProgressWrapper):
+    def _perform_disable(self, silent=False):
         """Disable specific entitlement
 
         @return: True on success, False otherwise.
         """
         if not livepatch.is_livepatch_installed():
             return True
-        cmd = [livepatch.LIVEPATCH_CMD, "disable"]
-        progress.progress(
-            messages.EXECUTING_COMMAND.format(command=" ".join(cmd))
-        )
-        system.subp(cmd, capture=True)
+        system.subp([livepatch.LIVEPATCH_CMD, "disable"], capture=True)
         return True
 
     def application_status(
@@ -246,17 +214,7 @@ class LivepatchEntitlement(UAEntitlement):
         if not livepatch.is_livepatch_installed():
             return (ApplicationStatus.DISABLED, messages.LIVEPATCH_NOT_ENABLED)
 
-        try:
-            livepatch_status = livepatch.status()
-        except exceptions.ProcessExecutionError as e:
-            return (
-                ApplicationStatus.WARNING,
-                messages.LIVEPATCH_CLIENT_FAILURE_WARNING.format(
-                    livepatch_error=e.stderr,
-                ),
-            )
-
-        if livepatch_status is None:
+        if livepatch.status() is None:
             # TODO(May want to parse INACTIVE/failure assessment)
             return (
                 ApplicationStatus.DISABLED,
@@ -291,7 +249,6 @@ class LivepatchEntitlement(UAEntitlement):
                 True,
                 messages.LIVEPATCH_KERNEL_UPGRADE_REQUIRED,
             )
-
         # if on_supported_kernel returns UNKNOWN we default to no warning
         # because there would be no way for a user to resolve the warning
         return False, None
@@ -310,7 +267,6 @@ class LivepatchEntitlement(UAEntitlement):
         orig_access: Dict[str, Any],
         deltas: Dict[str, Any],
         allow_enable: bool = False,
-        verbose: bool = True,
     ) -> bool:
         """Process any contract access deltas for this entitlement.
 
@@ -321,22 +277,19 @@ class LivepatchEntitlement(UAEntitlement):
         :param allow_enable: Boolean set True if allowed to perform the enable
             operation. When False, a message will be logged to inform the user
             about the recommended enabled service.
-        :param verbose: If True, display output to stdout
 
         :return: True when delta operations are processed; False when noop.
         """
-        if super().process_contract_deltas(
-            orig_access, deltas, allow_enable, verbose=verbose
-        ):
+        if super().process_contract_deltas(orig_access, deltas, allow_enable):
             return True  # Already processed parent class deltas
 
         delta_entitlement = deltas.get("entitlement", {})
         process_enable_default = delta_entitlement.get("obligations", {}).get(
-            "enableByDefault", False
+            "enabledByDefault", False
         )
 
         if process_enable_default:
-            enable_success, _ = self.enable(api.ProgressWrapper())
+            enable_success, _ = self.enable()
             return enable_success
 
         application_status, _ = self.application_status()
@@ -353,15 +306,12 @@ class LivepatchEntitlement(UAEntitlement):
                 "New livepatch directives or token. running "
                 "setup_livepatch_config"
             )
-
-            if verbose:
-                event.info(
-                    messages.SERVICE_UPDATING_CHANGED_DIRECTIVES.format(
-                        service=self.name
-                    )
+            event.info(
+                messages.SERVICE_UPDATING_CHANGED_DIRECTIVES.format(
+                    service=self.name
                 )
+            )
             return self.setup_livepatch_config(
-                progress=api.ProgressWrapper(),
                 process_directives=process_directives,
                 process_token=process_token,
             )
